@@ -22,7 +22,9 @@ describe 'mistral::api' do
       it { is_expected.to contain_mistral_config('api/api_workers').with_value( params[:api_workers] ) }
       it { is_expected.to contain_mistral_config('api/host').with_value( params[:bind_host] ) }
       it { is_expected.to contain_mistral_config('api/port').with_value( params[:bind_port] ) }
-      it { is_expected.to contain_mistral_config('oslo_middleware/enable_proxy_headers_parsing').with_value( params[:enable_proxy_headers_parsing] ) }
+      it { is_expected.to contain_oslo__middleware('mistral_config').with(
+        :enable_proxy_headers_parsing => params[:enable_proxy_headers_parsing],
+      )}
       it { is_expected.to contain_mistral_config('api/allow_action_execution_deletion').with_value( params[:allow_action_execution_deletion] ) }
 
     end
@@ -53,7 +55,9 @@ describe 'mistral::api' do
         params.merge!({:enable_proxy_headers_parsing => true })
       end
 
-      it { is_expected.to contain_mistral_config('oslo_middleware/enable_proxy_headers_parsing').with_value( params[:enable_proxy_headers_parsing] ) }
+      it { is_expected.to contain_oslo__middleware('mistral_config').with(
+        :enable_proxy_headers_parsing => params[:enable_proxy_headers_parsing],
+      )}
     end
 
     context 'with disabled service managing' do
