@@ -50,9 +50,10 @@ describe 'mistral' do
       is_expected.to contain_mistral_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_mistral_config('oslo_messaging_rabbit/rabbit_userid').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_mistral_config('oslo_messaging_rabbit/kombu_reconnect_delay').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_mistral_config('oslo_messaging_rabbit/kombu_failover_strategy').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_mistral_config('coordination/backend_url').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_mistral_config('coordination/heartbeat_interval').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_mistral_config('keystone_authtoken/auth_uri').with(
+      is_expected.to contain_mistral_config('keystone_authtoken/www_authenticate_uri').with(
        :value => 'http://localhost:5000'
       )
       is_expected.to contain_mistral_config('keystone_authtoken/auth_url').with(
@@ -235,7 +236,7 @@ describe 'mistral' do
     end
   end
 
-  describe 'with os_actions_keystone_endpoint overriden' do
+  describe 'with os_actions_keystone_endpoint overridden' do
     let :params do
       req_params.merge({
         :os_actions_endpoint_type => 'internal',
